Clazz.declarePackage("JSV.exception");
Clazz.load(["java.lang.Exception"], "JSV.exception.JSVException", null, function(){
var c$ = Clazz.declareType(JSV.exception, "JSVException", Exception);
});
;//5.0.1-v7 Fri Nov 14 10:17:11 CST 2025
